@@ -24,10 +24,14 @@ def Atmosphere(h0=_h0, h_top=_h_top, N_steps=_N_steps, model=_model):
 
     Parameters
     ----------
-    h0 : Ground level in km above sea level.
-    h_top : Top level of the atmosphere in km above sea level.
-    N_steps : Number of discretization steps.
-    model : CORSIKA atmospheric model. Presently either 1 or 17. More models to
+    h0 : float
+        Ground level in km above sea level.
+    h_top : float
+        Top level of the atmosphere in km above sea level.
+    N_steps : int
+        Number of discretization steps.
+    model : int
+        CORSIKA atmospheric model. Presently either 1 or 17. More models to
         be implemented.
 
     Returns
@@ -36,7 +40,7 @@ def Atmosphere(h0=_h0, h_top=_h_top, N_steps=_N_steps, model=_model):
 
     See also
     --------
-    Atmosphere object.
+    _Atmosphere : Atmosphere class.
     Track : Constructor of Track object.
     Profile: Constructor of Profile object.
     Shower : Constructor of Shower object.
@@ -112,22 +116,35 @@ class _Atmosphere(pd.DataFrame):
 
     Columns
     -------
-    h : Height in km above sea level.
-    X_vert : Vertical depth in g/cm^2.
-    rho : Mass density in g/cm^3.
-    temp : Temperature in K.
-    P : Pressure in hPa.
-    P_w : Partial pressure of water vapor in hPa.
-    E_th : Cherenkov energy threshold in MeV at 350 nm.
-    r_M : Moliere radius in km.
+    h : float
+        Height in km above sea level.
+    X_vert : float
+        Vertical depth in g/cm^2.
+    rho : float
+        Mass density in g/cm^3.
+    temp : float
+        Temperature in K.
+    P : float
+        Pressure in hPa.
+    P_w : float
+        Partial pressure of water vapor in hPa.
+    E_th : float
+        Cherenkov energy threshold in MeV at 350 nm.
+    r_M : float
+        Moliere radius in km.
 
     Attributes
     ----------
-    h0 : Ground level in km above sea level.
-    h_top : Top level of the atmosphere in km above sea level.
-    N_steps : Number of discretization steps.
-    h_step : Size of discretization step in km.
-    model : CORSIKA atmospheric model. Presently either 1 or 17. More models to
+    h0 : float
+        Ground level in km above sea level.
+    h_top : float
+        Top level of the atmosphere in km above sea level.
+    N_steps : int
+        Number of discretization steps.
+    h_step : float
+        Size of discretization step in km.
+    model : int
+        CORSIKA atmospheric model. Presently either 1 or 17. More models to
         be implemented.
 
     Methods
@@ -150,11 +167,13 @@ class _Atmosphere(pd.DataFrame):
 
         Parameters
         ----------
-        h : Scalar or array-type.
+        h : float or array_like
+            Height in km.
 
         Returns
         -------
-        Xv : Scalar or array-type.
+        Xv : float or array_like
+            Vertical depth in g/cm^2.
         """
         Xv, rho = self._get_Xv_rho(h)
         return Xv
@@ -165,11 +184,13 @@ class _Atmosphere(pd.DataFrame):
 
         Parameters
         ----------
-        h : Scalar or array-type.
+        h : float or array_like
+            Height in km.
 
         Returns
         -------
-        rho : Scalar or array-type.
+        rho : float or array_like
+            Mass density in g/cm^3.
         """
         Xv, rho = self._get_Xv_rho(h)
         return rho
@@ -187,11 +208,13 @@ class _Atmosphere(pd.DataFrame):
 
         Parameters
         ----------
-        Xv : Scalar or array-type.
+        Xv : float or array_like
+            Vertical depth in g/cm^2.
 
         Returns
         -------
-        h : Scalar or array-type.
+        h : float or array_like
+            Height in km.
         """
         if Xv == 0:
             return self.h_top
@@ -216,14 +239,18 @@ def _get_Xv_rho(h, model):
 
     Parameters
     ----------
-    h : Scalar or array-type.
-    model : CORSIKA atmospheric model. Presently either 1 or 17. More models to
+    h : float or array_like
+        Height in km.
+    model : int
+        CORSIKA atmospheric model. Presently either 1 or 17. More models to
         be implemented.
 
     Returns
     -------
-    Xv : Scalar or array-type.
-    rho : Scalar or array-type.
+    Xv : float or array_like
+        Vertical depth in g/cm^2.
+    rho : float or array_like
+        Mass density in g/cm^3.
     """
     # Some atmospheric models used in CORSIKA.
     # Each row contains the model parameters for a different atmospheric layer:
